@@ -712,6 +712,117 @@ my @names_edje = (
 	{name => 'EDJE_DRAG_DIR_X', 'macro' => 1},
 	{name => 'EDJE_DRAG_DIR_Y', 'macro' => 1},
 	{name => 'EDJE_DRAG_DIR_XY', 'macro' => 1},
+	#
+	{name => 'EDJE_ASPECT_CONTROL_NONE', 'macro' => 1},
+	{name => 'EDJE_ASPECT_CONTROL_NEITHER', 'macro' => 1},
+	{name => 'EDJE_ASPECT_CONTROL_HORIZONTAL', 'macro' => 1},
+	{name => 'EDJE_ASPECT_CONTROL_VERTICAL', 'macro' => 1},
+	{name => 'EDJE_ASPECT_CONTROL_BOTH', 'macro' => 1},
+	#
+	{name => 'EDJE_TEXT_FILTER_TEXT', 'macro' => 1},
+	{name => 'EDJE_TEXT_FILTER_FORMAT', 'macro' => 1},
+	{name => 'EDJE_TEXT_FILTER_MARKUP', 'macro' => 1},
+	#
+	{name => 'EDJE_INPUT_PANEL_LAYOUT_NORMAL_VARIATION_NORMAL', 'macro' => 1},
+	{name => 'EDJE_INPUT_PANEL_LAYOUT_NORMAL_VARIATION_FILENAME', 'macro' => 1},
+	{name => 'EDJE_INPUT_PANEL_LAYOUT_NORMAL_VARIATION_PERSON_NAME', 'macro' => 1},
+	#
+	{name => 'EDJE_INPUT_PANEL_LAYOUT_NUMBERONLY_VARIATION_NORMAL', 'macro' => 1},
+	{name => 'EDJE_INPUT_PANEL_LAYOUT_NUMBERONLY_VARIATION_SIGNED', 'macro' => 1},
+	{name => 'EDJE_INPUT_PANEL_LAYOUT_NUMBERONLY_VARIATION_DECIMAL', 'macro' => 1},
+	{name => 'EDJE_INPUT_PANEL_LAYOUT_NUMBERONLY_VARIATION_SIGNED_AND_DECIMAL', 'macro' => 1},
+	#
+	{name => 'EDJE_INPUT_PANEL_LAYOUT_PASSWORD_VARIATION_NORMAL', 'macro' => 1},
+	{name => 'EDJE_INPUT_PANEL_LAYOUT_PASSWORD_VARIATION_NUMBERONLY', 'macro' => 1},
+	#
+	{name => 'EDJE_TWEEN_MODE_NONE', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_LINEAR', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_SINUSOIDAL', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_ACCELERATE', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_DECELERATE', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_ACCELERATE_FACTOR', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_DECELERATE_FACTOR', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_SINUSOIDAL_FACTOR', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_DIVISOR_INTERP', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_BOUNCE', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_SPRING', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_CUBIC_BEZIER', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_LAST', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_MASK', 'macro' => 1},
+	{name => 'EDJE_TWEEN_MODE_OPT_FROM_CURRENT', 'macro' => 1},
+	#
+	{name => 'EDJE_ACTION_TYPE_NONE', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_STATE_SET', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_ACTION_STOP', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_SIGNAL_EMIT', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_DRAG_VAL_SET', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_DRAG_VAL_STEP', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_DRAG_VAL_PAGE', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_SCRIPT', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_FOCUS_SET', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_RESERVED00', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_FOCUS_OBJECT', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_PARAM_COPY', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_PARAM_SET', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_SOUND_SAMPLE', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_SOUND_TONE', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_PHYSICS_IMPULSE', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_PHYSICS_TORQUE_IMPULSE', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_PHYSICS_FORCE', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_PHYSICS_TORQUE', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_PHYSICS_FORCES_CLEAR', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_PHYSICS_VEL_SET', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_PHYSICS_ANG_VEL_SET', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_PHYSICS_STOP', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_PHYSICS_ROT_SET', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_VIBRATION_SAMPLE', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_MO', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_VG_ANIM_STOP', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_VG_ANIM_PAUSE', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_VG_ANIM_RESUME', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_VG_ANIM_PLAY', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_VG_ANIM_REWIND', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_VG_ANIM_LOOP', 'macro' => 1},
+	{name => 'EDJE_ACTION_TYPE_LAST', 'macro' => 1},
+	#
+	{name => 'EDJE_TEXT_EFFECT_NONE', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_PLAIN', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_OUTLINE', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_SOFT_OUTLINE', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_SHADOW', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_SOFT_SHADOW', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_OUTLINE_SHADOW', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_OUTLINE_SOFT_SHADOW', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_FAR_SHADOW', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_FAR_SOFT_SHADOW', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_GLOW', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_LAST', 'macro' => 1},
+	#
+	{name => 'EDJE_TEXT_EFFECT_SHADOW_DIRECTION_BOTTOM_RIGHT', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_SHADOW_DIRECTION_BOTTOM', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_SHADOW_DIRECTION_BOTTOM_LEFT', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_SHADOW_DIRECTION_LEFT', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_SHADOW_DIRECTION_TOP_LEFT', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_SHADOW_DIRECTION_TOP', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_SHADOW_DIRECTION_TOP_RIGHT', 'macro' => 1},
+	{name => 'EDJE_TEXT_EFFECT_SHADOW_DIRECTION_RIGHT', 'macro' => 1},
+	#
+	{name => 'EDJE_OBJECT_TABLE_HOMOGENEOUS_NONE', 'macro' => 1},
+	{name => 'EDJE_OBJECT_TABLE_HOMOGENEOUS_TABLE', 'macro' => 1},
+	{name => 'EDJE_OBJECT_TABLE_HOMOGENEOUS_ITEM', 'macro' => 1},
+	#
+	{name => 'EDJE_MESSAGE_NONE', 'macro' => 1},
+	{name => 'EDJE_MESSAGE_SIGNAL', 'macro' => 1},
+	{name => 'EDJE_MESSAGE_STRING', 'macro' => 1},
+	{name => 'EDJE_MESSAGE_INT', 'macro' => 1},
+	{name => 'EDJE_MESSAGE_FLOAT', 'macro' => 1},
+	{name => 'EDJE_MESSAGE_STRING_SET', 'macro' => 1},
+	{name => 'EDJE_MESSAGE_INT_SET', 'macro' => 1},
+	{name => 'EDJE_MESSAGE_FLOAT_SET', 'macro' => 1},
+	{name => 'EDJE_MESSAGE_STRING_INT', 'macro' => 1},
+	{name => 'EDJE_MESSAGE_STRING_FLOAT', 'macro' => 1},
+	{name => 'EDJE_MESSAGE_STRING_INT_SET', 'macro' => 1},
+	{name => 'EDJE_MESSAGE_STRING_FLOAT_SET', 'macro' => 1},
 	);
 
 	
